#!/bin/bash
# this script uses awattar api to receive costs per kWh for the next 24 hrs (after 14:00)
# the whole json response is copied to a temporary $awattardatafile and intereated thru it because of fair use 
# principle of Awattar API. It gets overwritten everytime the script is started.
# Set debugmode="Y" to see debuginfos, default is "N"
# Set showheaderline="Y" to show version info, scriptname and parameters
#
# Usage:    sh getnewprices.sh => returns hourly prices for the next 24 Hours from now
#           parameter -current => returns price for the current hour (now)
#
# precondiftion: jq commandline tool must be installed
# e.g. sudo apt-get install jq
#
# Parameter definition
scriptversion="1.0.0"
awattardatafile="awattarpreise.json"
debugmode="N"
showheaderline="Y"

#define timestamp function, needed for logging and output
timestamp() {
date +"%Y%m%d-%H%M%S"
}


if [ $showheaderline = "Y" ]
    then
    echo "$(timestamp) Script $0 Version $scriptversion started."
    echo "parameters provided: $@"
    echo "============================================================="
fi
#Unixzeit="$(date  '+%s')000"

if [ $debugmode = "Y" ]
then
    curl "https://api.awattar.at/v1/marketdata" > $awattardatafile
else
    curl -s "https://api.awattar.at/v1/marketdata" > $awattardatafile
fi

if [ $debugmode = "Y" ]
then
    echo "Debuginfo =========="

    if [ -f "$awattardatafile" ] 
    then
        echo "file $awattardatafile found"
    else
        echo "file $awattardatafile MISSING, exiting"
        exit 2
    fi
    echo "Debuginfo Ende ====="
fi

totalitems=$(jq '.data | length' $awattardatafile)

# get only the price for the current hour
if [ "$1" = "-current" ]
    then
    totalitems=1
fi

if [ $debugmode = "Y" ]
then
    echo "Debuginfo =========="
    echo "Total JSONItems in File:   $totalitems"
    echo "Debuginfo Ende ====="
fi

i=0

while [ $i -lt $totalitems ];
do

    Unixtimestamp=$(cat $awattardatafile | jq -r ".data[$i] | .start_timestamp")
    Unixtst4awattar=$((Unixtimestamp/1000))
    Marketprice=$(cat $awattardatafile | jq -r ".data[$i] | .marketprice")
    Marketprice=$(echo "scale=2; $Marketprice/10" |bc | awk '{printf "%.2f\n", $0}')
    Humanreadtimestamp=$(date -d "1970-01-01 UTC $Unixtst4awattar seconds" +"%Y.%m.%d  %H:%M")

if [ $debugmode = "Y" ]
then
    echo "Debuginfo =========="
    echo "Nummer $i"
    echo "Unixtimestamp         $Unixtimestamp"
    echo "Unixtst4awattar       $Unixtst4awattar"
    echo "Marketprice           $Marketprice"
    echo "Humanreadtimestamp    $Humanreadtimestamp"
    echo "Debuginfo Ende ====="
fi
    echo "$Humanreadtimestamp   $Marketprice"
    i=$((i+1))

done

